@@ -1,7 +1,7 @@
 package App::dateseq;
 
 our $DATE = '2015-09-25'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -69,37 +69,37 @@ _
     examples => [
         {
             summary => 'Generate dates from 2015-01-01 to 2015-01-31',
-            src => 'dateseq 2015-01-01 2015-01-31',
+            src => '[[prog]] 2015-01-01 2015-01-31',
             src_plang => 'bash',
         },
         {
             summary => 'Generate dates with increment of 3 days',
-            src => 'dateseq 2015-01-01 2015-01-31 -i P3D',
+            src => '[[prog]] 2015-01-01 2015-01-31 -i P3D',
             src_plang => 'bash',
         },
         {
             summary => 'Generate a CSV data',
-            src => 'dateseq 2010-01-01 2015-01-31 -f "%Y,%m,%d" --header "year,month,day"',
+            src => '[[prog]] 2010-01-01 2015-01-31 -f "%Y,%m,%d" --header "year,month,day"',
             src_plang => 'bash',
         },
         {
             summary => 'Generate periods (YYYY-MM)',
-            src => 'dateseq 2010-01-01 2015-12-31 -i P1M -f "%Y-%m"',
+            src => '[[prog]] 2010-01-01 2015-12-31 -i P1M -f "%Y-%m"',
             src_plang => 'bash',
         },
         {
             summary => 'List non-holidays in 2015 (using Indonesian holidays)',
-            src => 'setop --diff <(dateseq 2015-01-01 2015-12-31) <(list-id-holidays --year 2015)',
+            src => 'setop --diff <([[prog]] 2015-01-01 2015-12-31) <(list-id-holidays --year 2015)',
             src_plang => 'bash',
         },
         {
             summary => 'List non-holidays business days in 2015 (using Indonesian holidays)',
-            src => 'setop --diff <(dateseq 2015-01-01 2015-12-31 --business) <(list-id-holidays --year 2015)',
+            src => 'setop --diff <([[prog]] 2015-01-01 2015-12-31 --business) <(list-id-holidays --year 2015)',
             src_plang => 'bash',
         },
         {
             summary => 'Use with fsql',
-            src => q[dateseq 2010-01-01 2015-12-01 -f "%Y,%m" -i P1M --header "year,month" | fsql --add-csv - --add-csv data.csv -F YEAR -F MONTH 'SELECT year, month, data1 FROM stdin WHERE YEAR(data.date)=year AND MONTH(data.date)=month'],
+            src => q{[[prog]] 2010-01-01 2015-12-01 -f "%Y,%m" -i P1M --header "year,month" | fsql --add-csv - --add-csv data.csv -F YEAR -F MONTH 'SELECT year, month, data1 FROM stdin WHERE YEAR(data.date)=year AND MONTH(data.date)=month'},
             src_plang => 'bash',
         },
     ],
@@ -181,7 +181,7 @@ App::dateseq - Generate a sequence of dates
 
 =head1 VERSION
 
-This document describes version 0.04 of App::dateseq (from Perl distribution App-dateseq), released on 2015-09-25.
+This document describes version 0.05 of App::dateseq (from Perl distribution App-dateseq), released on 2015-09-25.
 
 =head1 FUNCTIONS
 
@@ -190,50 +190,6 @@ This document describes version 0.04 of App::dateseq (from Perl distribution App
 
 Generate a sequence of dates.
 
-Examples:
-
- dateseq();
-
-
-Generate dates from 2015-01-01 to 2015-01-31.
-
-
- dateseq();
-
-
-Generate dates with increment of 3 days.
-
-
- dateseq();
-
-
-Generate a CSV data.
-
-
- dateseq();
-
-
-Generate periods (YYYY-MM).
-
-
- dateseq();
-
-
-List non-holidays in 2015 (using Indonesian holidays).
-
-
- dateseq();
-
-
-List non-holidays business days in 2015 (using Indonesian holidays).
-
-
- dateseq();
-
-
-Use with fsql.
-
-
 This utility is similar to Unix C<seq> command, except that it generates a
 sequence of dates.
 
